@@ -1,4 +1,6 @@
-#-*- encoding: utf-8 -*-
+# -*- encoding: utf-8 -*-
+
+from __future__ import unicode_literals
 
 import unittest
 import os
@@ -11,15 +13,15 @@ from i18n.config import json_available, yaml_available
 from i18n import translations
 
 
-RESOURCE_FOLDER = os.path.join(os.path.dirname(__file__), 'resources')
+RESOURCE_FOLDER = os.path.join(os.path.dirname(__file__), "resources")
 
 
 class TestFileLoader(unittest.TestCase):
     def setUp(self):
         resource_loader.loaders = {}
         translations.container = {}
-        config.set('load_path', [os.path.join(RESOURCE_FOLDER, 'translations')])
-        config.set('filename_format', '{namespace}.{locale}.{format}')
+        config.set("load_path", [os.path.join(RESOURCE_FOLDER, "translations")])
+        config.set("filename_format", "{namespace}.{locale}.{format}")
         config.set("encoding", "utf-8")
 
     def test_load_unavailable_extension(self):
@@ -54,34 +56,34 @@ class TestFileLoader(unittest.TestCase):
         resource_loader.init_yaml_loader()
         data = resource_loader.load_resource(os.path.join(RESOURCE_FOLDER, "settings", "dummy_config.yml"), "settings")
         self.assertIn("foo", data)
-        self.assertEqual("bar", data['foo'])
+        self.assertEqual("bar", data["foo"])
 
     @unittest.skipUnless(json_available, "json library not available")
     def test_load_json_file(self):
         resource_loader.init_json_loader()
         data = resource_loader.load_resource(os.path.join(RESOURCE_FOLDER, "settings", "dummy_config.json"), "settings")
         self.assertIn("foo", data)
-        self.assertEqual("bar", data['foo'])
+        self.assertEqual("bar", data["foo"])
 
     def test_load_python_file(self):
         resource_loader.init_python_loader()
         data = resource_loader.load_resource(os.path.join(RESOURCE_FOLDER, "settings", "dummy_config.py"), "settings")
         self.assertIn("foo", data)
-        self.assertEqual("bar", data['foo'])
+        self.assertEqual("bar", data["foo"])
 
     @unittest.skipUnless(json_available, "json library not available")
     def test_load_file_with_strange_encoding(self):
         resource_loader.init_json_loader()
         config.set("encoding", "euc-jp")
         data = resource_loader.load_resource(os.path.join(RESOURCE_FOLDER, "settings", "eucjp_config.json"), "settings")
-        self.assertIn(u"ほげ", data)
-        self.assertEqual(u"ホゲ", data[u'ほげ'])
+        self.assertIn("ほげ", data)
+        self.assertEqual("ホゲ", data["ほげ"])
 
     def test_get_namespace_from_filepath_with_filename(self):
         tests = {
-            'foo': 'foo.ja.yml',
-            'foo.bar': os.path.join('foo', 'bar.ja.yml'),
-            'foo.bar.baz': os.path.join('foo', 'bar', 'baz.en.yml'),
+            "foo": "foo.ja.yml",
+            "foo.bar": os.path.join("foo", "bar.ja.yml"),
+            "foo.bar.baz": os.path.join("foo", "bar", "baz.en.yml"),
         }
         for expected, test_val in tests.items():
             namespace = resource_loader.get_namespace_from_filepath(test_val)
@@ -89,11 +91,11 @@ class TestFileLoader(unittest.TestCase):
 
     def test_get_namespace_from_filepath_without_filename(self):
         tests = {
-            '': 'ja.yml',
-            'foo': os.path.join('foo', 'ja.yml'),
-            'foo.bar': os.path.join('foo', 'bar', 'en.yml'),
+            "": "ja.yml",
+            "foo": os.path.join("foo", "ja.yml"),
+            "foo.bar": os.path.join("foo", "bar", "en.yml"),
         }
-        config.set('filename_format', '{locale}.{format}')
+        config.set("filename_format", "{locale}.{format}")
         for expected, test_val in tests.items():
             namespace = resource_loader.get_namespace_from_filepath(test_val)
             self.assertEqual(expected, namespace)
@@ -106,28 +108,39 @@ class TestFileLoader(unittest.TestCase):
         self.assertTrue(translations.has("foo.normal_key"))
         self.assertTrue(translations.has("foo.parent.nested_key"))
 
+    @unittest.skipUnless(json_available, "json library not available")
+    def test_load_plural(self):
+        resource_loader.init_yaml_loader()
+        resource_loader.load_translation_file("foo.en.yml", os.path.join(RESOURCE_FOLDER, "translations"))
+        self.assertTrue(translations.has("foo.mail_number"))
+        translated_plural = translations.get("foo.mail_number")
+        self.assertIsInstance(translated_plural, dict)
+        self.assertEqual(translated_plural["zero"], "You do not have any mail.")
+        self.assertEqual(translated_plural["one"], "You have a new mail.")
+        self.assertEqual(translated_plural["many"], "You have %{count} new mails.")
+
     @unittest.skipUnless(yaml_available, "yaml library not available")
     def test_search_translation_yaml(self):
         resource_loader.init_yaml_loader()
-        config.set('file_format', 'yml')
-        resource_loader.search_translation('foo.normal_key')
+        config.set("file_format", "yml")
+        resource_loader.search_translation("foo.normal_key")
         self.assertTrue(translations.has("foo.normal_key"))
 
     @unittest.skipUnless(json_available, "json library not available")
     def test_search_translation_json(self):
         resource_loader.init_json_loader()
-        config.set('file_format', 'json')
+        config.set("file_format", "json")
 
-        resource_loader.search_translation('bar.baz.qux')
-        self.assertTrue(translations.has('bar.baz.qux'))
+        resource_loader.search_translation("bar.baz.qux")
+        self.assertTrue(translations.has("bar.baz.qux"))
 
     @unittest.skipUnless(json_available, "json library not available")
     def test_search_translation_without_ns(self):
         resource_loader.init_json_loader()
-        config.set('file_format', 'json')
-        config.set('filename_format', '{locale}.{format}')
-        resource_loader.search_translation('foo')
-        self.assertTrue(translations.has('foo'))
+        config.set("file_format", "json")
+        config.set("filename_format", "{locale}.{format}")
+        resource_loader.search_translation("foo")
+        self.assertTrue(translations.has("foo"))
 
 
 suite = unittest.TestLoader().loadTestsFromTestCase(TestFileLoader)
