@@ -1,3 +1,7 @@
+# -*- encoding: utf-8 -*-
+
+from __future__ import unicode_literals
+
 import unittest
 import os
 import os.path
@@ -9,6 +13,7 @@ from i18n import config
 
 RESOURCE_FOLDER = os.path.dirname(__file__) + os.sep + 'resources' + os.sep
 
+
 class TestTranslationFormat(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
@@ -55,6 +60,10 @@ class TestTranslationFormat(unittest.TestCase):
         config.set('fallback', 'fr')
         self.assertEqual(t('foo.hello', name='Bob'), 'Salut Bob !')
 
+    def test_fallback_from_resource(self):
+        config.set('fallback', 'ja')
+        self.assertEqual(t('foo.fallback_key'), 'フォールバック')
+
     def test_basic_placeholder(self):
         self.assertEqual(t('foo.hi', name='Bob'), 'Hello Bob !')
 
@@ -83,6 +92,5 @@ class TestTranslationFormat(unittest.TestCase):
         with self.assertRaises(KeyError):
             t('foo.bad_plural', count=0)
 
-
     def test_default(self):
         self.assertEqual(t('inexistent_key', default='foo'), 'foo')
